summaryrefslogtreecommitdiffstats
path: root/sys/geom/geom_bsd.c
diff options
context:
space:
mode:
authorphk <phk@FreeBSD.org>2003-05-02 06:33:59 +0000
committerphk <phk@FreeBSD.org>2003-05-02 06:33:59 +0000
commit0a7a0e5019592fce5a9d600aa03f88de7c768389 (patch)
tree2781452016d6987307617bf041d228f9fa24f5c8 /sys/geom/geom_bsd.c
parent077126a4bec479afef1551082d84286a35c45ee0 (diff)
downloadFreeBSD-src-0a7a0e5019592fce5a9d600aa03f88de7c768389.zip
FreeBSD-src-0a7a0e5019592fce5a9d600aa03f88de7c768389.tar.gz
Use g_slice_spoiled() rather than g_std_spoiled()
Diffstat (limited to 'sys/geom/geom_bsd.c')
-rw-r--r--sys/geom/geom_bsd.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/geom/geom_bsd.c b/sys/geom/geom_bsd.c
index 1f289d8..f66ada3 100644
--- a/sys/geom/geom_bsd.c
+++ b/sys/geom/geom_bsd.c
@@ -788,10 +788,10 @@ g_bsd_taste(struct g_class *mp, struct g_provider *pp, int flags)
return (gp);
/*
* ...else push the "self-destruct" button, by spoiling our own
* consumer. This triggers a call to g_std_spoiled which will
* dismantle what was setup.
*/
- g_std_spoiled(cp);
+ g_slice_spoiled(cp);
return (NULL);
}
OpenPOWER on IntegriCloud
@@ -788,10 +788,10 @@ g_bsd_taste(struct g_class *mp, struct g_provider *pp, int flags)
/*
* ...else push the "self-destruct" button, by spoiling our own
- * consumer. This triggers a call to g_std_spoiled which will
+ * consumer. This triggers a call to g_slice_spoiled which will
* dismantle what was setup.
*/